@@ -13,7 +13,7 @@ def danbooru():
     """
     client_data = {
         'as_json': True,
-        'client_name': 'danbooru_',
+        'client_name': 'Danbooru',
         'client_url': 'https://danbooru.donmai.us/posts.json?tags=',
     }
     return GalleryClient(client_data)
@@ -56,7 +56,21 @@ def konachan():
     client_data = {
         'as_json': True,
         'client_name': 'Konachan',
-        'client_url': 'https://konachan.com/post.json?limit=1000&tags='
+        'client_url': 'https://konachan.com/post.json?tags='
+    }
+    return GalleryClient(client_data)
+
+
+def safebooru():
+    """
+    Returns an GalleryClient instance with Safbooru data.
+    :return:
+    :rtype: opalart.GalleryClient
+    """
+    client_data = {
+        'as_json': False,
+        'client_name': 'Safebooru',
+        'client_url': 'http://safebooru.org/index.php?page=dapi&s=post&q=index&tags=',
     }
     return GalleryClient(client_data)
 
@@ -112,7 +126,7 @@ class GalleryClient(object):
         self.as_json = client_data.get('as_json')
         self.client_name = client_data.get('client_name')
         self.client_url = client_data.get('client_url')
-        self.headers = {'User-Agent': 'opalart/0.1.1'}
+        self.headers = {'User-Agent': 'opalart/0.1.2'}
         self.include_hash = False
         self.limit = None
         self.tags = None
